@@ -35,5 +35,13 @@ dualgreedy <- function(A,nf,ns,etol=0,mattest=TRUE)
                     PACKAGE="edesign"
                     )
    
-    list(S=ans$S,det=ans$det)
+    ret <- list(S=ans$S,det=ans$det)
+    ret$A <- A
+    ret$na <- na
+    ret$nf <- nf
+    ret$ns <- ns
+    ret$ne <- ne
+    ret$method <- "dual greedy"
+    class(ret) <- "monet"
+    ret
   }
